# guppylang-internals

This packages contains the internals of the Guppy compiler. 

See `guppylang` for the package providing the user-facing language frontend.

# Install

The package can be installed via `pip`.

```sh
pip install guppylang-internals
```

# Development

See [DEVELOPMENT.md] information on how to develop and contribute to this package.

  [DEVELOPMENT.md]: https://github.com/CQCL/guppylang/blob/main/DEVELOPMENT.md

## License

This project is licensed under Apache License, Version 2.0 ([LICENCE][] or http://www.apache.org/licenses/LICENSE-2.0).

  [LICENCE]: https://github.com/CQCL/guppylang/blob/main/LICENCE